==> kafka-3.2.3-src.tgz: kafka-3.2.3-src/streams/src/main/java/org/apache/kafka/streams/kstream/internals/KStreamPeek.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.kstream.internals;

import org.apache.kafka.streams.kstream.ForeachAction;
import org.apache.kafka.streams.processor.api.ContextualProcessor;
import org.apache.kafka.streams.processor.api.Processor;
import org.apache.kafka.streams.processor.api.ProcessorSupplier;
import org.apache.kafka.streams.processor.api.Record;

class KStreamPeek<K, V> implements ProcessorSupplier<K, V, K, V> {

    private final ForeachAction<K, V> action;

    public KStreamPeek(final ForeachAction<K, V> action) {
        this.action = action;
    }

    @Override
    public Processor<K, V, K, V> get() {
        return new KStreamPeekProcessor();
    }

    private class KStreamPeekProcessor extends ContextualProcessor<K, V, K, V> {
        @Override
        public void process(final Record<K, V> record) {
            action.apply(record.key(), record.value());
            context().forward(record);
        }
    }

}

==> kafka-4.0.1-src.tgz: kafka-4.0.1-src/streams/src/main/java/org/apache/kafka/streams/kstream/internals/KStreamPeek.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.kstream.internals;

import org.apache.kafka.streams.kstream.ForeachAction;
import org.apache.kafka.streams.processor.api.ContextualFixedKeyProcessor;
import org.apache.kafka.streams.processor.api.FixedKeyProcessor;
import org.apache.kafka.streams.processor.api.FixedKeyProcessorSupplier;
import org.apache.kafka.streams.processor.api.FixedKeyRecord;

class KStreamPeek<K, V> implements FixedKeyProcessorSupplier<K, V, V> {

    private final ForeachAction<K, V> action;

    public KStreamPeek(final ForeachAction<K, V> action) {
        this.action = action;
    }

    @Override
    public FixedKeyProcessor<K, V, V> get() {
        return new KStreamPeekProcessor();
    }

    private class KStreamPeekProcessor extends ContextualFixedKeyProcessor<K, V, V> {
        @Override
        public void process(final FixedKeyRecord<K, V> record) {
            action.apply(record.key(), record.value());
            context().forward(record);
        }
    }

}
